@@ -3,19 +3,18 @@ package FSM::Basic;
 use 5.006;
 use strict;
 use warnings;
-use Carp;
-use Data::Dumper;
+
 =head1 NAME
 
 FSM::Basic -  Finite state machine using HASH as state definitions
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -117,6 +116,12 @@ The keys are the states name.
 
 =back
 
+It is perfectly possible to add extra tag not used by FSM::Basic for generic purpose.
+Check examples/fake_bash_ssh1.*
+Take a look at timout and timer usage
+In this example if destination IP from the SSH connection is available, the file IP.json is used as definition 
+(with fallback to fake_bash1.pl)
+
 =cut
 
 sub new
@@ -166,7 +171,7 @@ sub run
             $output = delete( $self->{states_list}{$self->{state}}{info_once} ) . $output;
         }
         my $state;
-        if ( $in eq '' && $self->{previous_output} =~ /\[(.+)\]/ )
+        if (exists $self->{previous_output} && $in eq '' && $self->{previous_output} =~ /\[(.+)\]/ )
         {
             $in = $1;
         }
@@ -237,6 +242,14 @@ sub run
     #    }
 }
 
+sub set
+{
+    my ( $self, $in ) = @_;
+    $self->{previous_state}  = $self->{state};
+    $self->{previous_output} = $self->{states_list}{$self->{state}}{output} // '';
+    $self->{state}           = $in if exists $self->{states_list}{$in};
+}
+
 #sub edit
 #{
 #    my ( $self, $in ) = @_;
